@@ -46,7 +46,7 @@
 #include <sys/time.h>
 #include <sys/ioctl.h>
 /* "The nice thing about standards..." */
-#if defined (__linux__) || defined (__bsdi__)
+#if defined (__linux__) || defined (__bsdi__) || defined (HAVE_SYS_SOUNDCARD_H)
 #include <sys/soundcard.h>
 #else
 #if defined (__FreeBSD__)
