@@ -1,30 +1,21 @@
-#ifdef GOM_ENABLE_X_GOMII
-/*
- * gom_iface_x.c: x gomii
- */
-
-/* 
- * This file is part of the package
+/* gom, Gom is nOt yet another (Audio) Mixer.
  *
- * gom, Gom is nOt yet another Mixer
+ * Copyright (C) 1996-2004  Stephan A Suerken <absurd@olurdix.de>
  *
- * (c) Stephan Suerken <suerken@fh-worms.de> 1996, 1997
- */
-
-/*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 /*
@@ -33,7 +24,7 @@
  */
 
 /* Copyright by Hannu Savolainen 1993
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
  * met: 1. Redistributions of source code must retain the above copyright
@@ -41,7 +32,7 @@
  * Redistributions in binary form must reproduce the above copyright notice,
  * this list of conditions and the following disclaimer in the documentation
  * and/or other materials provided with the distribution.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS `AS IS' AND ANY
  * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -53,13 +44,19 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- * 
+ *
+ */
+#include "gom.h"
+
+#ifdef GOM_ENABLE_X_GOMII
+
+/*
+ * gom_iface_x.c: x gomii
  */
 
 /*
  * INCLUDES
  */
-#include "gom.h"
 #include <xview/frame.h>
 #include <xview/panel.h>
 
@@ -126,7 +123,7 @@ gom_iface_x_init();
  * Some Helps
  */
 
-void 
+void
 gom_iface_x_center(Panel panel, Panel_item item)
 {
   int p_width  = xv_get(panel, XV_WIDTH);
@@ -136,7 +133,7 @@ gom_iface_x_center(Panel panel, Panel_item item)
 	 NULL);
 }
 
-void 
+void
 gom_iface_x_flush_right(Panel panel, Panel_item item)
 {
   int p_width  = xv_get(panel, XV_WIDTH);
@@ -159,13 +156,13 @@ gom_iface_x_scroll_show_page()
 /*
  * Custom gom_info()
  */
-void 
+void
 gom_iface_x_info(enum gom_info_types kind, char * fmt, va_list vargs)
 {
   char line[255];
-  
+
   vsnprintf(line, 255, fmt, vargs);
-  
+
   if (gom_info_scroll())
     {
       if ((++gom_iface_x_info_line) >= GOM_IFACE_X_SCROLL_LINES)
@@ -192,7 +189,7 @@ gom_iface_x_info(enum gom_info_types kind, char * fmt, va_list vargs)
 /*
  * Custom option arg
  */
-char * 
+char *
 gom_iface_x_get_option_arg(char * prompt)
 {
   static char option_arg[100];
@@ -223,15 +220,15 @@ gom_iface_x_get_option_arg(char * prompt)
 	  volume = gom_iface_x_action_xv_value & 0x7f;
 	  snprintf(option_arg, 100, "%d", volume);
 	  break;
-	  
+
 	case 'r':
 	  snprintf(option_arg, 100, "%d", !gom_driver_c_r(gom_mixer_c_current()));
 	  break;
-	  
+
 	case 'k':
 	  snprintf(option_arg, 100, "%d", !gom_mixer_c_l(gom_mixer_c_current()));
 	  break;
-	  
+
 	default:
 	  break;
 	}
@@ -239,7 +236,7 @@ gom_iface_x_get_option_arg(char * prompt)
   return option_arg;
 }
 
-void 
+void
 gom_iface_x_refresh_channel (int c)
 {
   int cc;
@@ -247,7 +244,7 @@ gom_iface_x_refresh_channel (int c)
   /* set all volumes */
   for(cc=gom_driver_c_c_first(c); cc > -1; cc=gom_driver_c_c_next(c, cc, +1))
     xv_set(gom_iface_x_volume[c][cc], PANEL_VALUE, gom_driver_c_c_v(c, cc), NULL);
-  
+
   /* set record */
   if (gom_driver_c_r(c) > -1)
     xv_set(gom_iface_x_rec_src[c],
@@ -258,44 +255,44 @@ gom_iface_x_refresh_channel (int c)
   xv_set(gom_iface_x_lock[c],
 	 PANEL_VALUE, gom_mixer_c_l(c),
 	 NULL);
-};
+}
 
-void 
+void
 gom_iface_x_update(enum gom_gomii_refresh_stage stage,
 		   int new_channel)
 {
   int c;
-  
+
   switch (stage)
     {
     case GOM_GOMII_REFRESH_INIT:
       gom_iface_x_closeup();
       gom_iface_x_init();
 
-      /* Only a greeting (and we are very smart about it (which really isn't actually needed) ;) */ 
+      /* Only a greeting (and we are very smart about it (which really isn't actually needed) ;) */
       gom_info(GOM_INFO_NORMAL,
 	       "Welcome%sto the x gomii!",
 	       gom_iface_x_deja_vu ? " back " : " ");
-      
-    case GOM_GOMII_REFRESH_PAGE: 
+
+    case GOM_GOMII_REFRESH_PAGE:
       /* redraw headline + center it */
       xv_set(gom_iface_x_mixer_message,
 	     PANEL_LABEL_STRING, gom_driver_d(), NULL);
       gom_iface_x_center(gom_iface_x_panel, gom_iface_x_mixer_message);
 
-    case GOM_GOMII_REFRESH_CHANNELS: 
-      for(c=gom_driver_c_first(); c > -1; c=gom_driver_c_next(c, +1)) 
+    case GOM_GOMII_REFRESH_CHANNELS:
+      for(c=gom_driver_c_first(); c > -1; c=gom_driver_c_next(c, +1))
 	gom_iface_x_refresh_channel(c);
- 
+
       /* update last refresh time */
       xv_set(gom_iface_x_last_refresh_message,
 	     PANEL_LABEL_STRING, gom_gomii_last_refresh_str(), NULL);
       gom_iface_x_flush_right(gom_iface_x_panel, gom_iface_x_last_refresh_message);
       break;
- 
-    case GOM_GOMII_REFRESH_CURRENT_CHANNEL: 
+
+    case GOM_GOMII_REFRESH_CURRENT_CHANNEL:
       gom_iface_x_refresh_channel(gom_mixer_c_current());
-      
+
     default:
       break;
     }
@@ -304,19 +301,19 @@ gom_iface_x_update(enum gom_gomii_refresh_stage stage,
     xv_main_loop(gom_iface_x_frame);
 }
 
-void 
+void
 gom_iface_x_refresh()
 {
   gom_iface_x_update(GOM_GOMII_REFRESH_CHANNELS, gom_mixer_c_current());
 }
 
-void 
+void
 gom_iface_x_scroll_return(Panel_item item, int value, Event * event)
 {
   xv_window_return(gom_iface_x_scroll_frame);
-};
+}
 
-void 
+void
 gom_iface_x_scroll_create()
 {
   int i;
@@ -331,7 +328,7 @@ gom_iface_x_scroll_create()
  					  PANEL_LAYOUT, PANEL_VERTICAL,
  					  PANEL_ITEM_Y_GAP, 0,
 					  NULL);
-  
+
   for (i=0; i < GOM_IFACE_X_SCROLL_LINES; ++i)
     gom_iface_x_scroll_gadget[i] = xv_create(gom_iface_x_scroll_panel, PANEL_MESSAGE,
 					PANEL_LABEL_STRING, " ",
@@ -339,13 +336,13 @@ gom_iface_x_scroll_create()
   xv_set(gom_iface_x_scroll_panel,
 	 PANEL_ITEM_Y_GAP, 20,
 	 NULL);
-  
-  gom_iface_x_scroll_continue = 
+
+  gom_iface_x_scroll_continue =
     xv_create(gom_iface_x_scroll_panel, PANEL_BUTTON,
 	      PANEL_NOTIFY_PROC, gom_iface_x_scroll_return,
 	      PANEL_LABEL_STRING, "Continue",
 	      NULL);
-};
+}
 
 void
 gom_iface_x_pre_scroll()
@@ -376,7 +373,7 @@ gom_iface_x_post_scroll()
   gom_info(GOM_INFO_NORMAL, "Back from scrolling...");
 }
 
-void 
+void
 gom_iface_x_action (Panel_item item, int value, Event * event)
 {
   enum gom_gomii_refresh_stage stage = GOM_GOMII_REFRESH_INIT;
@@ -404,7 +401,7 @@ gom_iface_x_action (Panel_item item, int value, Event * event)
     {
       sscanf((char *) xv_get(gom_iface_x_action_string, PANEL_VALUE), "%c", (char *) &gom_iface_x_action_action);
     }
-  
+
   switch (gom_iface_x_action_action)
     {
       /* x gomii specials */
@@ -413,7 +410,7 @@ gom_iface_x_action (Panel_item item, int value, Event * event)
       stage = GOM_GOMII_REFRESH_NO;
       break;
 
-    default: 
+    default:
       stage = gom_action(GOM_INFO_NORMAL,
 			 gom_iface_x_action_action, 0,
 			 gom_iface_x_get_option_arg,
@@ -421,7 +418,7 @@ gom_iface_x_action (Panel_item item, int value, Event * event)
       break;
     }
   gom_iface_x_update(stage, gom_mixer_c_current());
-};
+}
 
 void
 gom_iface_x_init()
@@ -463,11 +460,11 @@ gom_iface_x_init()
   /* realize a x=1x3=y rectangle (y = 3*x) */
   for (cboxes_x = 1; ((cboxes_x * 3) * cboxes_x) < avail; cboxes_x++);
   cboxes_y = 3*cboxes_x;
-  
+
   /* Maybe this is necessary for *something*, so I leave this as comment... */
   /* xv_init(XV_INIT_ARGC_PTR_ARGV, &argc, argv, NULL); */
-  
-  gom_iface_x_frame = (Frame) xv_create(XV_NULL, FRAME, 
+
+  gom_iface_x_frame = (Frame) xv_create(XV_NULL, FRAME,
 				   FRAME_LABEL, GOM_TITLE,
 				   NULL);
 
@@ -499,35 +496,34 @@ gom_iface_x_init()
   y_top = y;
 
   n = 0;
-  for(c=gom_driver_c_first(); c > -1; c=gom_driver_c_next(c, +1)) 
-    { 
+  for(c=gom_driver_c_first(); c > -1; c=gom_driver_c_next(c, +1))
+    {
       x_base = x;
       y_base = y;
 
       gom_iface_x_label[c] = xv_create (gom_iface_x_panel, PANEL_MESSAGE,
-					PANEL_LABEL_STRING, gom_driver_c_name(c),
+					PANEL_LABEL_STRING, gom_driver_c_name(c, 1),
 					PANEL_LABEL_BOLD, TRUE,
 					XV_Y, y,
 					XV_X, x+58, /* STATIC */
 					NULL);
-      
+
       /* Next line! */
       y += xv_get(gom_iface_x_label[c], XV_HEIGHT);
       y_tmp = y;
       x_tmp = x;
-      
+
       /* volume sliders */
       for(cc=gom_driver_c_c_first(c); cc > -1; cc=gom_driver_c_c_next(c, cc, +1))
 	{
-	  gom_iface_x_volume[c][cc] = 
-	    (Panel_item) xv_create(gom_iface_x_panel, PANEL_SLIDER, 
+	  gom_iface_x_volume[c][cc] =
+	    (Panel_item) xv_create(gom_iface_x_panel, PANEL_SLIDER,
 				   XV_KEY_DATA, gom_iface_x_action_action_key, 'l',
 				   XV_KEY_DATA, gom_iface_x_action_c_key, c,
 				   XV_KEY_DATA, gom_iface_x_action_c_c_key, cc,
 				   PANEL_NOTIFY_PROC, gom_iface_x_action,
-							     
+
 				   PANEL_NOTIFY_LEVEL, PANEL_ALL,
-				   /* PANEL_LABEL_STRING, gom_driver_c_c_name(c, cc), */
 				   PANEL_SHOW_RANGE, FALSE,
 				   PANEL_SHOW_VALUE, TRUE,
 				   PANEL_SLIDER_END_BOXES, TRUE,
@@ -551,7 +547,7 @@ gom_iface_x_init()
 				   XV_KEY_DATA, gom_iface_x_action_c_key, c,
 				   XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
 				   PANEL_NOTIFY_PROC, gom_iface_x_action,
-				   
+
 				   PANEL_CHOICE_STRINGS, "R", NULL,
 				   XV_Y, y,
 				   XV_X, x,
@@ -565,7 +561,7 @@ gom_iface_x_init()
 	  /* Next line! (let's say, there MUST be at least one channel ...) */
 	  y += xv_get(gom_iface_x_volume[c][0], XV_HEIGHT);
 	}
-      
+
       /* lock button */
       gom_iface_x_lock[c] =
 	(Panel_item) xv_create(gom_iface_x_panel, PANEL_TOGGLE,
@@ -573,18 +569,18 @@ gom_iface_x_init()
 			       XV_KEY_DATA, gom_iface_x_action_c_key, c,
 			       XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
 			       PANEL_NOTIFY_PROC, gom_iface_x_action,
-			       
+
 			       PANEL_CHOICE_STRINGS, "L", NULL,
 			       PANEL_LAYOUT, PANEL_VERTICAL,
 			       XV_Y, y,
 			       XV_X, x,
 			       PANEL_VALUE, gom_mixer_c_l(c),
 			       NULL);
-      
+
       /* Next line! */
       y += xv_get(gom_iface_x_volume[c][0], XV_HEIGHT) + 5; /* STATIC */
-  
-      ymax = y > ymax ? y : ymax;	  
+
+      ymax = y > ymax ? y : ymax;
       /* setting x, y */
       ++n;
       if (n >= cboxes_y)
@@ -624,10 +620,10 @@ gom_iface_x_init()
 			       NULL);
 
   /* Next line! */
-  y += xv_get(gom_iface_x_info_text, XV_HEIGHT) + y_gap;  
+  y += xv_get(gom_iface_x_info_text, XV_HEIGHT) + y_gap;
   x = 4; /* STATIC */
 
-  gom_iface_x_action_button = 
+  gom_iface_x_action_button =
     xv_create(gom_iface_x_panel, PANEL_BUTTON,
 	      XV_KEY_DATA, gom_iface_x_action_c_key, -1,
 	      XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
@@ -637,7 +633,7 @@ gom_iface_x_init()
 	      PANEL_LABEL_STRING, "Action",
 	      NULL);
 
-  gom_iface_x_action_string = 
+  gom_iface_x_action_string =
     xv_create(gom_iface_x_panel, PANEL_TEXT,
 	      XV_KEY_DATA, gom_iface_x_action_c_key, -1,
 	      XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
@@ -647,32 +643,32 @@ gom_iface_x_init()
 	      XV_Y, y,
 	      XV_X, (x += xv_get(gom_iface_x_action_button, XV_WIDTH)+5), /* STATIC */
 	      NULL);
-  
-  gom_iface_x_help_button = 
+
+  gom_iface_x_help_button =
     xv_create(gom_iface_x_panel, PANEL_BUTTON,
 	      XV_KEY_DATA, gom_iface_x_action_action_key, 'h',
 	      XV_KEY_DATA, gom_iface_x_action_c_key, -1,
 	      XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
-	      
+
 	      PANEL_NOTIFY_PROC, gom_iface_x_action,
 	      XV_Y, y,
 	      XV_X, (x += xv_get(gom_iface_x_action_string, XV_WIDTH)+5), /* STATIC */
 	      PANEL_LABEL_STRING, "Help",
 	      NULL);
 
-  gom_iface_x_quit_button = 
+  gom_iface_x_quit_button =
     xv_create(gom_iface_x_panel, PANEL_BUTTON,
 	      XV_KEY_DATA, gom_iface_x_action_action_key, 'q',
 	      XV_KEY_DATA, gom_iface_x_action_c_key, -1,
 	      XV_KEY_DATA, gom_iface_x_action_c_c_key, -1,
-	      
+
 	      PANEL_NOTIFY_PROC, gom_iface_x_action,
 	      XV_Y, y,
 	      XV_X, (x += xv_get(gom_iface_x_help_button, XV_WIDTH)),
-	      
+
 	      PANEL_LABEL_STRING, "Quit",
 	      NULL);
-  
+
   gom_iface_x_flush_right(gom_iface_x_panel, gom_iface_x_quit_button);
 
   /* create final fitting panel & frame size */
@@ -709,8 +705,14 @@ void
 gom_iface_x()
 {
   gom_iface_x_deja_vu = 1;
-  
+
   /* pop up the window */
   gom_iface_x_update(GOM_GOMII_REFRESH_INIT, gom_mixer_c_current());
 }
+
+#else
+
+/** ISO C forbids empty source files. */
+int gom_iface_c_global_dummy = 0;
+
 #endif
